==> nextcloud-app-mail-1.5.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/zh_TW.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "自動偵測失敗，請改用手動輸入",
    "Updating account failed: " : "更新帳戶失敗",
    "Creating account failed: " : "建立帳號失敗：",
    "Mail" : "電子郵件",
    "Auto" : "自動",
    "Name" : "名字",
    "Mail Address" : "郵件地址",
    "Password" : "密碼",
    "Manual" : "手動",
    "IMAP Settings" : "IMAP設定",
    "IMAP Host" : "IMAP 主機",
    "IMAP Security" : "IMAP Security",
    "None" : "無",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP 連接埠",
    "IMAP User" : "IMAP 帳號",
    "IMAP Password" : "IMAP 密碼",
    "SMTP Settings" : "SMTP設定",
    "SMTP Host" : "SMTP 主機",
    "SMTP Security" : "SMTP Security",
    "SMTP Port" : "SMTP 連接埠",
    "SMTP User" : "SMTP 帳號",
    "SMTP Password" : "SMTP 密碼",
    "Save" : "儲存",
    "Connect" : "連線",
    "Add mail account" : "新增郵件帳戶",
    "Use Gravatar and favicon avatars" : "使用個人化大頭貼與網站圖示",
    "Select account" : "選擇帳號",
    "Subject" : "主旨",
    "Upload attachment" : "上傳附件",
    "Add attachment from Files" : "從雲端檔案中加入附件",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "需要一個方式加密您的電子郵件嗎？請安裝 Mailvelope 瀏覽器擴充程式",
    "Sending …" : "傳送中…",
    "Go back" : "返回",
    "Retry" : "重試",
    "Message sent!" : "信件已寄出",
    "Send" : "傳送",
    "Choose a file to add as attachment" : "選擇檔案作為附件",
    "No messages in this folder" : "此收件匣中沒有信件",
    "Unselect" : "取消選取",
    "Select" : "選取",
    "Delete" : "刪除",
    "Important" : "重要",
    "Favorites" : "我的最愛",
    "Other" : "其他",
    "Attachments" : "附件",
    "Import into calendar" : "匯入到日曆",
    "Download attachment" : "下載附檔",
    "Save to Files" : "儲存至雲端檔案",
    "Unnamed" : "未命名",
    "Choose a folder to store the attachment in" : "選擇存放附件的目錄",
    "Save all to Files" : "全部儲存至檔案",
    "The images have been blocked to protect your privacy." : "為維護您的隱私，圖片將不會被載入",
    "Show images from this sender" : "顯示來自此寄件者的圖片",
    "New message" : "新信件",
    "Settings" : "設定",
    "Quota" : "用量",
    "Add folder" : "新增資料夾",
    "Saving" : "儲存中...",
    "Remove account" : "移除帳號",
    "Loading …" : "載入中 ...",
    "Cancel" : "取消",
    "Show all folders" : "顯示所有收件匣",
    "Collapse folders" : "收合收件匣",
    "Mark all as read" : "全部標示為已閱讀",
    "Edit name" : "編輯名稱",
    "Clear cache" : "清除快取",
    "Delete folder" : "刪除資料夾",
    "Signature" : "簽章",
    "Reply" : "回覆",
    "Forward" : "向前",
    "General" : "一般",
    "User" : "使用者",
    "Host" : "主機",
    "Port" : "連接埠",
    "Change name" : "更改名稱",
    "Keyboard shortcut" : "快速鍵",
    "Keyboard shortcuts" : "快速鍵",
    "Speed up your Mail experience with these quick shortcuts." : "使用快速鍵來加速您的操作體驗",
    "Compose new message" : "撰寫新信件",
    "Newer message" : "較新的信件",
    "Older message" : "較舊的信件",
    "Toggle star" : "加上/移除星號",
    "Toggle unread" : "標示未讀/已讀",
    "Search" : "搜尋",
    "Refresh" : "重整",
    "Connect your mail account" : "連結外部信箱",
    "All" : "全部",
    "Archive" : "封存",
    "Drafts" : "草稿",
    "All inboxes" : "所有收件匣",
    "Inbox" : "收件匣",
    "Junk" : "垃圾郵件",
    "Sent" : "寄件備份",
    "Trash" : "回收筒",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n則新信件\n來自 {from}"],
    "Nextcloud Mail" : "Nextcloud 郵件",
    "Could not load {tag}{name}{endtag}" : "無法載入 {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "載入 {tag}{name}{endtag} 時出現問題",
    "Could not load your message" : "無法載入您的信件",
    "Could not load the desired message" : "無法載入所選的信件",
    "Could not load the message" : "無法載入信件",
    "Error loading message" : "載入信件錯誤",
    "Forwarding to %s" : "正在轉寄給%s",
    "Click here if you are not automatically redirected within the next few seconds." : "如果未在幾秒內跳轉，請點擊這裡",
    "Redirect" : "跳轉",
    "The link leads to %s" : "該連結導向至 %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "若不想拜訪該頁，您可以回到<a href=\"%s\">郵件</a>",
    "Continue to %s" : "前往 %s"
},
"nplurals=1; plural=0;");

==> nextcloud-app-mail-1.7.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/zh_TW.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "自動偵測失敗，請改用手動輸入",
    "Updating account failed: " : "更新帳戶失敗",
    "Creating account failed: " : "建立帳號失敗：",
    "Mail" : "電子郵件",
    "Auto" : "自動",
    "Name" : "名字",
    "Mail Address" : "郵件地址",
    "Password" : "密碼",
    "Manual" : "手動",
    "IMAP Settings" : "IMAP設定",
    "IMAP Host" : "IMAP 主機",
    "IMAP Security" : "IMAP Security",
    "None" : "無",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP 連接埠",
    "IMAP User" : "IMAP 帳號",
    "IMAP Password" : "IMAP 密碼",
    "SMTP Settings" : "SMTP設定",
    "SMTP Host" : "SMTP 主機",
    "SMTP Security" : "SMTP Security",
    "SMTP Port" : "SMTP 連接埠",
    "SMTP User" : "SMTP 帳號",
    "SMTP Password" : "SMTP 密碼",
    "Save" : "儲存",
    "Connect" : "連線",
    "Add mail account" : "新增郵件帳戶",
    "Use Gravatar and favicon avatars" : "使用個人化大頭貼與網站圖示",
    "Select account" : "選擇帳號",
    "Subject" : "主旨",
    "Upload attachment" : "上傳附件",
    "Add attachment from Files" : "從雲端檔案中加入附件",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "需要一個方式加密您的電子郵件嗎？請安裝 Mailvelope 瀏覽器擴充程式",
    "Sending …" : "傳送中…",
    "Go back" : "返回",
    "Retry" : "重試",
    "Message sent!" : "信件已寄出",
    "Send" : "傳送",
    "Choose a file to add as attachment" : "選擇檔案作為附件",
    "No messages in this folder" : "此收件匣中沒有信件",
    "Unselect" : "取消選取",
    "Select" : "選取",
    "Move" : "移動",
    "Delete" : "刪除",
    "Choose target folder" : "選擇目標資料夾",
    "No more subfolders in here" : "這裡沒有其他子資料夾了",
    "Choose" : "選擇",
    "Important" : "重要",
    "Favorites" : "我的最愛",
    "Other" : "其他",
    "Attachments" : "附件",
    "Import into calendar" : "匯入到日曆",
    "Download attachment" : "下載附檔",
    "Save to Files" : "儲存至雲端檔案",
    "Unnamed" : "未命名",
    "Choose a folder to store the attachment in" : "選擇存放附件的目錄",
    "Save all to Files" : "全部儲存至檔案",
    "The images have been blocked to protect your privacy." : "為維護您的隱私，圖片將不會被載入",
    "Show images from this sender" : "顯示來自此寄件者的圖片",
    "New message" : "新信件",
    "Settings" : "設定",
    "Quota" : "用量",
    "Add folder" : "新增資料夾",
    "Saving" : "儲存中...",
    "Remove account" : "移除帳號",
    "Loading …" : "載入中 ...",
    "Cancel" : "取消",
    "Show all folders" : "顯示所有收件匣",
    "Collapse folders" : "收合收件匣",
    "Mark all as read" : "全部標示為已閱讀",
    "Edit name" : "編輯名稱",
    "Clear cache" : "清除快取",
    "Delete folder" : "刪除資料夾",
    "Signature" : "簽章",
    "Reply" : "回覆",
    "Forward" : "向前",
    "General" : "一般",
    "User" : "使用者",
    "Host" : "主機",
    "Port" : "連接埠",
    "Change name" : "更改名稱",
    "Keyboard shortcut" : "快速鍵",
    "Keyboard shortcuts" : "快速鍵",
    "Speed up your Mail experience with these quick shortcuts." : "使用快速鍵來加速您的操作體驗",
    "Compose new message" : "撰寫新信件",
    "Newer message" : "較新的信件",
    "Older message" : "較舊的信件",
    "Toggle star" : "加上/移除星號",
    "Toggle unread" : "標示未讀/已讀",
    "Search" : "搜尋",
    "Refresh" : "重整",
    "Connect your mail account" : "連結外部信箱",
    "All" : "全部",
    "Archive" : "封存",
    "Drafts" : "草稿",
    "All inboxes" : "所有收件匣",
    "Inbox" : "收件匣",
    "Junk" : "垃圾郵件",
    "Sent" : "寄件備份",
    "Trash" : "回收筒",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n則新信件\n來自 {from}"],
    "Nextcloud Mail" : "Nextcloud 郵件",
    "Could not load {tag}{name}{endtag}" : "無法載入 {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "載入 {tag}{name}{endtag} 時出現問題",
    "Could not load your message" : "無法載入您的信件",
    "Could not load the desired message" : "無法載入所選的信件",
    "Could not load the message" : "無法載入信件",
    "Error loading message" : "載入信件錯誤",
    "Forwarding to %s" : "正在轉寄給%s",
    "Click here if you are not automatically redirected within the next few seconds." : "如果未在幾秒內跳轉，請點擊這裡",
    "Redirect" : "跳轉",
    "The link leads to %s" : "該連結導向至 %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "若不想拜訪該頁，您可以回到<a href=\"%s\">郵件</a>",
    "Continue to %s" : "前往 %s"
},
"nplurals=1; plural=0;");
